@@ -7,5 +7,5 @@ geomerge.neighbor <- function(polygon_input) {
   # default is row-standardized weights
   wts1 <- nb2listw(nb_lags[[1]],zero.policy = TRUE)  # islands should be cut, so no need for zero.policy=TRUE
   wts2 <- nb2listw(nb_lags[[2]],zero.policy = TRUE)
-  list(wts1=wts1, wts2=wts2)
+  return(list(wts1=wts1, wts2=wts2))
 }
\ No newline at end of file
